@@ -1,7 +1,7 @@
 "returnBy" <-
 function(x,dat,by,...)
 {
-  bp <- breakpoints(dat,by,TRUE);
+  bp <- endpoints(dat,by);
   end.value <- period.apply(cumprod(1+x),bp, function(x) x[length(x)]);
   per.change <- diff(c(1,end.value))/c(1,end.value[-length(end.value)]);
   zret <- zoo(cbind(end.value,per.change),index(dat)[bp]);
